# Changelog

```{spelling}
Changelog
```

```{include} ../CHANGELOG.md
:end-before: <!-- towncrier release notes start -->
:start-after: (DO-NOT-REMOVE-versioning-promise-START)

```

<!-- markdownlint-disable-next-line no-space-in-emphasis -->
## {{ release_l }}, as of {sub-ref}`today` _{subscript}`/UNRELEASED DRAFT/`_

```{important} This version is not yet released and is under active development
```

```{towncrier-draft-entries}
```

```{include} ../CHANGELOG.md
:start-after: <!-- towncrier release notes start -->

```
